"""CylindricalGearProfileModification"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.type_enforcement import enforce_parameter_types
from mastapy._private._internal import constructor, utility
from mastapy._private.gears.micro_geometry import _593
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_CYLINDRICAL_GEAR_PROFILE_MODIFICATION = python_net_import(
    "SMT.MastaAPI.Gears.GearDesigns.Cylindrical.MicroGeometry",
    "CylindricalGearProfileModification",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.utility_gui.charts import _1919
    from mastapy._private.gears.gear_designs.cylindrical import _1055
    from mastapy._private.gears.gear_designs.cylindrical.micro_geometry import (
        _1161,
        _1138,
    )
    from mastapy._private.gears.micro_geometry import _590

    Self = TypeVar("Self", bound="CylindricalGearProfileModification")
    CastSelf = TypeVar(
        "CastSelf",
        bound="CylindricalGearProfileModification._Cast_CylindricalGearProfileModification",
    )


__docformat__ = "restructuredtext en"
__all__ = ("CylindricalGearProfileModification",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_CylindricalGearProfileModification:
    """Special nested class for casting CylindricalGearProfileModification to subclasses."""

    __parent__: "CylindricalGearProfileModification"

    @property
    def profile_modification(self: "CastSelf") -> "_593.ProfileModification":
        return self.__parent__._cast(_593.ProfileModification)

    @property
    def modification(self: "CastSelf") -> "_590.Modification":
        from mastapy._private.gears.micro_geometry import _590

        return self.__parent__._cast(_590.Modification)

    @property
    def cylindrical_gear_profile_modification_at_face_width_position(
        self: "CastSelf",
    ) -> "_1138.CylindricalGearProfileModificationAtFaceWidthPosition":
        from mastapy._private.gears.gear_designs.cylindrical.micro_geometry import _1138

        return self.__parent__._cast(
            _1138.CylindricalGearProfileModificationAtFaceWidthPosition
        )

    @property
    def cylindrical_gear_profile_modification(
        self: "CastSelf",
    ) -> "CylindricalGearProfileModification":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class CylindricalGearProfileModification(_593.ProfileModification):
    """CylindricalGearProfileModification

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _CYLINDRICAL_GEAR_PROFILE_MODIFICATION

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def barrelling_peak_point_diameter(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.BarrellingPeakPointDiameter

        if temp is None:
            return 0.0

        return temp

    @barrelling_peak_point_diameter.setter
    @enforce_parameter_types
    def barrelling_peak_point_diameter(self: "Self", value: "float") -> None:
        self.wrapped.BarrellingPeakPointDiameter = (
            float(value) if value is not None else 0.0
        )

    @property
    def barrelling_peak_point_radius(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.BarrellingPeakPointRadius

        if temp is None:
            return 0.0

        return temp

    @barrelling_peak_point_radius.setter
    @enforce_parameter_types
    def barrelling_peak_point_radius(self: "Self", value: "float") -> None:
        self.wrapped.BarrellingPeakPointRadius = (
            float(value) if value is not None else 0.0
        )

    @property
    def barrelling_peak_point_roll_angle(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.BarrellingPeakPointRollAngle

        if temp is None:
            return 0.0

        return temp

    @barrelling_peak_point_roll_angle.setter
    @enforce_parameter_types
    def barrelling_peak_point_roll_angle(self: "Self", value: "float") -> None:
        self.wrapped.BarrellingPeakPointRollAngle = (
            float(value) if value is not None else 0.0
        )

    @property
    def barrelling_peak_point_roll_distance(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.BarrellingPeakPointRollDistance

        if temp is None:
            return 0.0

        return temp

    @barrelling_peak_point_roll_distance.setter
    @enforce_parameter_types
    def barrelling_peak_point_roll_distance(self: "Self", value: "float") -> None:
        self.wrapped.BarrellingPeakPointRollDistance = (
            float(value) if value is not None else 0.0
        )

    @property
    def evaluation_lower_limit_diameter(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.EvaluationLowerLimitDiameter

        if temp is None:
            return 0.0

        return temp

    @evaluation_lower_limit_diameter.setter
    @enforce_parameter_types
    def evaluation_lower_limit_diameter(self: "Self", value: "float") -> None:
        self.wrapped.EvaluationLowerLimitDiameter = (
            float(value) if value is not None else 0.0
        )

    @property
    def evaluation_lower_limit_diameter_for_zero_root_relief(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.EvaluationLowerLimitDiameterForZeroRootRelief

        if temp is None:
            return 0.0

        return temp

    @evaluation_lower_limit_diameter_for_zero_root_relief.setter
    @enforce_parameter_types
    def evaluation_lower_limit_diameter_for_zero_root_relief(
        self: "Self", value: "float"
    ) -> None:
        self.wrapped.EvaluationLowerLimitDiameterForZeroRootRelief = (
            float(value) if value is not None else 0.0
        )

    @property
    def evaluation_lower_limit_radius(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.EvaluationLowerLimitRadius

        if temp is None:
            return 0.0

        return temp

    @evaluation_lower_limit_radius.setter
    @enforce_parameter_types
    def evaluation_lower_limit_radius(self: "Self", value: "float") -> None:
        self.wrapped.EvaluationLowerLimitRadius = (
            float(value) if value is not None else 0.0
        )

    @property
    def evaluation_lower_limit_radius_for_zero_root_relief(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.EvaluationLowerLimitRadiusForZeroRootRelief

        if temp is None:
            return 0.0

        return temp

    @evaluation_lower_limit_radius_for_zero_root_relief.setter
    @enforce_parameter_types
    def evaluation_lower_limit_radius_for_zero_root_relief(
        self: "Self", value: "float"
    ) -> None:
        self.wrapped.EvaluationLowerLimitRadiusForZeroRootRelief = (
            float(value) if value is not None else 0.0
        )

    @property
    def evaluation_lower_limit_roll_angle(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.EvaluationLowerLimitRollAngle

        if temp is None:
            return 0.0

        return temp

    @evaluation_lower_limit_roll_angle.setter
    @enforce_parameter_types
    def evaluation_lower_limit_roll_angle(self: "Self", value: "float") -> None:
        self.wrapped.EvaluationLowerLimitRollAngle = (
            float(value) if value is not None else 0.0
        )

    @property
    def evaluation_lower_limit_roll_angle_for_zero_root_relief(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.EvaluationLowerLimitRollAngleForZeroRootRelief

        if temp is None:
            return 0.0

        return temp

    @evaluation_lower_limit_roll_angle_for_zero_root_relief.setter
    @enforce_parameter_types
    def evaluation_lower_limit_roll_angle_for_zero_root_relief(
        self: "Self", value: "float"
    ) -> None:
        self.wrapped.EvaluationLowerLimitRollAngleForZeroRootRelief = (
            float(value) if value is not None else 0.0
        )

    @property
    def evaluation_lower_limit_roll_distance(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.EvaluationLowerLimitRollDistance

        if temp is None:
            return 0.0

        return temp

    @evaluation_lower_limit_roll_distance.setter
    @enforce_parameter_types
    def evaluation_lower_limit_roll_distance(self: "Self", value: "float") -> None:
        self.wrapped.EvaluationLowerLimitRollDistance = (
            float(value) if value is not None else 0.0
        )

    @property
    def evaluation_lower_limit_roll_distance_for_zero_root_relief(
        self: "Self",
    ) -> "float":
        """float"""
        temp = self.wrapped.EvaluationLowerLimitRollDistanceForZeroRootRelief

        if temp is None:
            return 0.0

        return temp

    @evaluation_lower_limit_roll_distance_for_zero_root_relief.setter
    @enforce_parameter_types
    def evaluation_lower_limit_roll_distance_for_zero_root_relief(
        self: "Self", value: "float"
    ) -> None:
        self.wrapped.EvaluationLowerLimitRollDistanceForZeroRootRelief = (
            float(value) if value is not None else 0.0
        )

    @property
    def evaluation_of_linear_root_relief_diameter(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.EvaluationOfLinearRootReliefDiameter

        if temp is None:
            return 0.0

        return temp

    @evaluation_of_linear_root_relief_diameter.setter
    @enforce_parameter_types
    def evaluation_of_linear_root_relief_diameter(self: "Self", value: "float") -> None:
        self.wrapped.EvaluationOfLinearRootReliefDiameter = (
            float(value) if value is not None else 0.0
        )

    @property
    def evaluation_of_linear_root_relief_radius(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.EvaluationOfLinearRootReliefRadius

        if temp is None:
            return 0.0

        return temp

    @evaluation_of_linear_root_relief_radius.setter
    @enforce_parameter_types
    def evaluation_of_linear_root_relief_radius(self: "Self", value: "float") -> None:
        self.wrapped.EvaluationOfLinearRootReliefRadius = (
            float(value) if value is not None else 0.0
        )

    @property
    def evaluation_of_linear_root_relief_roll_angle(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.EvaluationOfLinearRootReliefRollAngle

        if temp is None:
            return 0.0

        return temp

    @evaluation_of_linear_root_relief_roll_angle.setter
    @enforce_parameter_types
    def evaluation_of_linear_root_relief_roll_angle(
        self: "Self", value: "float"
    ) -> None:
        self.wrapped.EvaluationOfLinearRootReliefRollAngle = (
            float(value) if value is not None else 0.0
        )

    @property
    def evaluation_of_linear_root_relief_roll_distance(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.EvaluationOfLinearRootReliefRollDistance

        if temp is None:
            return 0.0

        return temp

    @evaluation_of_linear_root_relief_roll_distance.setter
    @enforce_parameter_types
    def evaluation_of_linear_root_relief_roll_distance(
        self: "Self", value: "float"
    ) -> None:
        self.wrapped.EvaluationOfLinearRootReliefRollDistance = (
            float(value) if value is not None else 0.0
        )

    @property
    def evaluation_of_linear_tip_relief_diameter(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.EvaluationOfLinearTipReliefDiameter

        if temp is None:
            return 0.0

        return temp

    @evaluation_of_linear_tip_relief_diameter.setter
    @enforce_parameter_types
    def evaluation_of_linear_tip_relief_diameter(self: "Self", value: "float") -> None:
        self.wrapped.EvaluationOfLinearTipReliefDiameter = (
            float(value) if value is not None else 0.0
        )

    @property
    def evaluation_of_linear_tip_relief_radius(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.EvaluationOfLinearTipReliefRadius

        if temp is None:
            return 0.0

        return temp

    @evaluation_of_linear_tip_relief_radius.setter
    @enforce_parameter_types
    def evaluation_of_linear_tip_relief_radius(self: "Self", value: "float") -> None:
        self.wrapped.EvaluationOfLinearTipReliefRadius = (
            float(value) if value is not None else 0.0
        )

    @property
    def evaluation_of_linear_tip_relief_roll_angle(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.EvaluationOfLinearTipReliefRollAngle

        if temp is None:
            return 0.0

        return temp

    @evaluation_of_linear_tip_relief_roll_angle.setter
    @enforce_parameter_types
    def evaluation_of_linear_tip_relief_roll_angle(
        self: "Self", value: "float"
    ) -> None:
        self.wrapped.EvaluationOfLinearTipReliefRollAngle = (
            float(value) if value is not None else 0.0
        )

    @property
    def evaluation_of_linear_tip_relief_roll_distance(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.EvaluationOfLinearTipReliefRollDistance

        if temp is None:
            return 0.0

        return temp

    @evaluation_of_linear_tip_relief_roll_distance.setter
    @enforce_parameter_types
    def evaluation_of_linear_tip_relief_roll_distance(
        self: "Self", value: "float"
    ) -> None:
        self.wrapped.EvaluationOfLinearTipReliefRollDistance = (
            float(value) if value is not None else 0.0
        )

    @property
    def evaluation_of_parabolic_root_relief_diameter(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.EvaluationOfParabolicRootReliefDiameter

        if temp is None:
            return 0.0

        return temp

    @evaluation_of_parabolic_root_relief_diameter.setter
    @enforce_parameter_types
    def evaluation_of_parabolic_root_relief_diameter(
        self: "Self", value: "float"
    ) -> None:
        self.wrapped.EvaluationOfParabolicRootReliefDiameter = (
            float(value) if value is not None else 0.0
        )

    @property
    def evaluation_of_parabolic_root_relief_radius(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.EvaluationOfParabolicRootReliefRadius

        if temp is None:
            return 0.0

        return temp

    @evaluation_of_parabolic_root_relief_radius.setter
    @enforce_parameter_types
    def evaluation_of_parabolic_root_relief_radius(
        self: "Self", value: "float"
    ) -> None:
        self.wrapped.EvaluationOfParabolicRootReliefRadius = (
            float(value) if value is not None else 0.0
        )

    @property
    def evaluation_of_parabolic_root_relief_roll_angle(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.EvaluationOfParabolicRootReliefRollAngle

        if temp is None:
            return 0.0

        return temp

    @evaluation_of_parabolic_root_relief_roll_angle.setter
    @enforce_parameter_types
    def evaluation_of_parabolic_root_relief_roll_angle(
        self: "Self", value: "float"
    ) -> None:
        self.wrapped.EvaluationOfParabolicRootReliefRollAngle = (
            float(value) if value is not None else 0.0
        )

    @property
    def evaluation_of_parabolic_root_relief_roll_distance(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.EvaluationOfParabolicRootReliefRollDistance

        if temp is None:
            return 0.0

        return temp

    @evaluation_of_parabolic_root_relief_roll_distance.setter
    @enforce_parameter_types
    def evaluation_of_parabolic_root_relief_roll_distance(
        self: "Self", value: "float"
    ) -> None:
        self.wrapped.EvaluationOfParabolicRootReliefRollDistance = (
            float(value) if value is not None else 0.0
        )

    @property
    def evaluation_of_parabolic_tip_relief_diameter(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.EvaluationOfParabolicTipReliefDiameter

        if temp is None:
            return 0.0

        return temp

    @evaluation_of_parabolic_tip_relief_diameter.setter
    @enforce_parameter_types
    def evaluation_of_parabolic_tip_relief_diameter(
        self: "Self", value: "float"
    ) -> None:
        self.wrapped.EvaluationOfParabolicTipReliefDiameter = (
            float(value) if value is not None else 0.0
        )

    @property
    def evaluation_of_parabolic_tip_relief_radius(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.EvaluationOfParabolicTipReliefRadius

        if temp is None:
            return 0.0

        return temp

    @evaluation_of_parabolic_tip_relief_radius.setter
    @enforce_parameter_types
    def evaluation_of_parabolic_tip_relief_radius(self: "Self", value: "float") -> None:
        self.wrapped.EvaluationOfParabolicTipReliefRadius = (
            float(value) if value is not None else 0.0
        )

    @property
    def evaluation_of_parabolic_tip_relief_roll_angle(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.EvaluationOfParabolicTipReliefRollAngle

        if temp is None:
            return 0.0

        return temp

    @evaluation_of_parabolic_tip_relief_roll_angle.setter
    @enforce_parameter_types
    def evaluation_of_parabolic_tip_relief_roll_angle(
        self: "Self", value: "float"
    ) -> None:
        self.wrapped.EvaluationOfParabolicTipReliefRollAngle = (
            float(value) if value is not None else 0.0
        )

    @property
    def evaluation_of_parabolic_tip_relief_roll_distance(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.EvaluationOfParabolicTipReliefRollDistance

        if temp is None:
            return 0.0

        return temp

    @evaluation_of_parabolic_tip_relief_roll_distance.setter
    @enforce_parameter_types
    def evaluation_of_parabolic_tip_relief_roll_distance(
        self: "Self", value: "float"
    ) -> None:
        self.wrapped.EvaluationOfParabolicTipReliefRollDistance = (
            float(value) if value is not None else 0.0
        )

    @property
    def evaluation_upper_limit_diameter(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.EvaluationUpperLimitDiameter

        if temp is None:
            return 0.0

        return temp

    @evaluation_upper_limit_diameter.setter
    @enforce_parameter_types
    def evaluation_upper_limit_diameter(self: "Self", value: "float") -> None:
        self.wrapped.EvaluationUpperLimitDiameter = (
            float(value) if value is not None else 0.0
        )

    @property
    def evaluation_upper_limit_diameter_for_zero_tip_relief(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.EvaluationUpperLimitDiameterForZeroTipRelief

        if temp is None:
            return 0.0

        return temp

    @evaluation_upper_limit_diameter_for_zero_tip_relief.setter
    @enforce_parameter_types
    def evaluation_upper_limit_diameter_for_zero_tip_relief(
        self: "Self", value: "float"
    ) -> None:
        self.wrapped.EvaluationUpperLimitDiameterForZeroTipRelief = (
            float(value) if value is not None else 0.0
        )

    @property
    def evaluation_upper_limit_radius(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.EvaluationUpperLimitRadius

        if temp is None:
            return 0.0

        return temp

    @evaluation_upper_limit_radius.setter
    @enforce_parameter_types
    def evaluation_upper_limit_radius(self: "Self", value: "float") -> None:
        self.wrapped.EvaluationUpperLimitRadius = (
            float(value) if value is not None else 0.0
        )

    @property
    def evaluation_upper_limit_radius_for_zero_tip_relief(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.EvaluationUpperLimitRadiusForZeroTipRelief

        if temp is None:
            return 0.0

        return temp

    @evaluation_upper_limit_radius_for_zero_tip_relief.setter
    @enforce_parameter_types
    def evaluation_upper_limit_radius_for_zero_tip_relief(
        self: "Self", value: "float"
    ) -> None:
        self.wrapped.EvaluationUpperLimitRadiusForZeroTipRelief = (
            float(value) if value is not None else 0.0
        )

    @property
    def evaluation_upper_limit_roll_angle(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.EvaluationUpperLimitRollAngle

        if temp is None:
            return 0.0

        return temp

    @evaluation_upper_limit_roll_angle.setter
    @enforce_parameter_types
    def evaluation_upper_limit_roll_angle(self: "Self", value: "float") -> None:
        self.wrapped.EvaluationUpperLimitRollAngle = (
            float(value) if value is not None else 0.0
        )

    @property
    def evaluation_upper_limit_roll_angle_for_zero_tip_relief(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.EvaluationUpperLimitRollAngleForZeroTipRelief

        if temp is None:
            return 0.0

        return temp

    @evaluation_upper_limit_roll_angle_for_zero_tip_relief.setter
    @enforce_parameter_types
    def evaluation_upper_limit_roll_angle_for_zero_tip_relief(
        self: "Self", value: "float"
    ) -> None:
        self.wrapped.EvaluationUpperLimitRollAngleForZeroTipRelief = (
            float(value) if value is not None else 0.0
        )

    @property
    def evaluation_upper_limit_roll_distance(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.EvaluationUpperLimitRollDistance

        if temp is None:
            return 0.0

        return temp

    @evaluation_upper_limit_roll_distance.setter
    @enforce_parameter_types
    def evaluation_upper_limit_roll_distance(self: "Self", value: "float") -> None:
        self.wrapped.EvaluationUpperLimitRollDistance = (
            float(value) if value is not None else 0.0
        )

    @property
    def evaluation_upper_limit_roll_distance_for_zero_tip_relief(
        self: "Self",
    ) -> "float":
        """float"""
        temp = self.wrapped.EvaluationUpperLimitRollDistanceForZeroTipRelief

        if temp is None:
            return 0.0

        return temp

    @evaluation_upper_limit_roll_distance_for_zero_tip_relief.setter
    @enforce_parameter_types
    def evaluation_upper_limit_roll_distance_for_zero_tip_relief(
        self: "Self", value: "float"
    ) -> None:
        self.wrapped.EvaluationUpperLimitRollDistanceForZeroTipRelief = (
            float(value) if value is not None else 0.0
        )

    @property
    def linear_relief_isoagmadin(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.LinearReliefISOAGMADIN

        if temp is None:
            return 0.0

        return temp

    @linear_relief_isoagmadin.setter
    @enforce_parameter_types
    def linear_relief_isoagmadin(self: "Self", value: "float") -> None:
        self.wrapped.LinearReliefISOAGMADIN = float(value) if value is not None else 0.0

    @property
    def linear_relief_ldp(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.LinearReliefLDP

        if temp is None:
            return 0.0

        return temp

    @linear_relief_ldp.setter
    @enforce_parameter_types
    def linear_relief_ldp(self: "Self", value: "float") -> None:
        self.wrapped.LinearReliefLDP = float(value) if value is not None else 0.0

    @property
    def linear_relief_vdi(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.LinearReliefVDI

        if temp is None:
            return 0.0

        return temp

    @linear_relief_vdi.setter
    @enforce_parameter_types
    def linear_relief_vdi(self: "Self", value: "float") -> None:
        self.wrapped.LinearReliefVDI = float(value) if value is not None else 0.0

    @property
    def pressure_angle_modification(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.PressureAngleModification

        if temp is None:
            return 0.0

        return temp

    @pressure_angle_modification.setter
    @enforce_parameter_types
    def pressure_angle_modification(self: "Self", value: "float") -> None:
        self.wrapped.PressureAngleModification = (
            float(value) if value is not None else 0.0
        )

    @property
    def profile_modification_chart(self: "Self") -> "_1919.TwoDChartDefinition":
        """mastapy._private.utility_gui.charts.TwoDChartDefinition

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ProfileModificationChart

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def start_of_linear_root_relief_diameter(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.StartOfLinearRootReliefDiameter

        if temp is None:
            return 0.0

        return temp

    @start_of_linear_root_relief_diameter.setter
    @enforce_parameter_types
    def start_of_linear_root_relief_diameter(self: "Self", value: "float") -> None:
        self.wrapped.StartOfLinearRootReliefDiameter = (
            float(value) if value is not None else 0.0
        )

    @property
    def start_of_linear_root_relief_radius(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.StartOfLinearRootReliefRadius

        if temp is None:
            return 0.0

        return temp

    @start_of_linear_root_relief_radius.setter
    @enforce_parameter_types
    def start_of_linear_root_relief_radius(self: "Self", value: "float") -> None:
        self.wrapped.StartOfLinearRootReliefRadius = (
            float(value) if value is not None else 0.0
        )

    @property
    def start_of_linear_root_relief_roll_angle(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.StartOfLinearRootReliefRollAngle

        if temp is None:
            return 0.0

        return temp

    @start_of_linear_root_relief_roll_angle.setter
    @enforce_parameter_types
    def start_of_linear_root_relief_roll_angle(self: "Self", value: "float") -> None:
        self.wrapped.StartOfLinearRootReliefRollAngle = (
            float(value) if value is not None else 0.0
        )

    @property
    def start_of_linear_root_relief_roll_distance(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.StartOfLinearRootReliefRollDistance

        if temp is None:
            return 0.0

        return temp

    @start_of_linear_root_relief_roll_distance.setter
    @enforce_parameter_types
    def start_of_linear_root_relief_roll_distance(self: "Self", value: "float") -> None:
        self.wrapped.StartOfLinearRootReliefRollDistance = (
            float(value) if value is not None else 0.0
        )

    @property
    def start_of_linear_tip_relief_diameter(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.StartOfLinearTipReliefDiameter

        if temp is None:
            return 0.0

        return temp

    @start_of_linear_tip_relief_diameter.setter
    @enforce_parameter_types
    def start_of_linear_tip_relief_diameter(self: "Self", value: "float") -> None:
        self.wrapped.StartOfLinearTipReliefDiameter = (
            float(value) if value is not None else 0.0
        )

    @property
    def start_of_linear_tip_relief_radius(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.StartOfLinearTipReliefRadius

        if temp is None:
            return 0.0

        return temp

    @start_of_linear_tip_relief_radius.setter
    @enforce_parameter_types
    def start_of_linear_tip_relief_radius(self: "Self", value: "float") -> None:
        self.wrapped.StartOfLinearTipReliefRadius = (
            float(value) if value is not None else 0.0
        )

    @property
    def start_of_linear_tip_relief_roll_angle(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.StartOfLinearTipReliefRollAngle

        if temp is None:
            return 0.0

        return temp

    @start_of_linear_tip_relief_roll_angle.setter
    @enforce_parameter_types
    def start_of_linear_tip_relief_roll_angle(self: "Self", value: "float") -> None:
        self.wrapped.StartOfLinearTipReliefRollAngle = (
            float(value) if value is not None else 0.0
        )

    @property
    def start_of_linear_tip_relief_roll_distance(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.StartOfLinearTipReliefRollDistance

        if temp is None:
            return 0.0

        return temp

    @start_of_linear_tip_relief_roll_distance.setter
    @enforce_parameter_types
    def start_of_linear_tip_relief_roll_distance(self: "Self", value: "float") -> None:
        self.wrapped.StartOfLinearTipReliefRollDistance = (
            float(value) if value is not None else 0.0
        )

    @property
    def start_of_parabolic_root_relief_diameter(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.StartOfParabolicRootReliefDiameter

        if temp is None:
            return 0.0

        return temp

    @start_of_parabolic_root_relief_diameter.setter
    @enforce_parameter_types
    def start_of_parabolic_root_relief_diameter(self: "Self", value: "float") -> None:
        self.wrapped.StartOfParabolicRootReliefDiameter = (
            float(value) if value is not None else 0.0
        )

    @property
    def start_of_parabolic_root_relief_radius(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.StartOfParabolicRootReliefRadius

        if temp is None:
            return 0.0

        return temp

    @start_of_parabolic_root_relief_radius.setter
    @enforce_parameter_types
    def start_of_parabolic_root_relief_radius(self: "Self", value: "float") -> None:
        self.wrapped.StartOfParabolicRootReliefRadius = (
            float(value) if value is not None else 0.0
        )

    @property
    def start_of_parabolic_root_relief_roll_angle(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.StartOfParabolicRootReliefRollAngle

        if temp is None:
            return 0.0

        return temp

    @start_of_parabolic_root_relief_roll_angle.setter
    @enforce_parameter_types
    def start_of_parabolic_root_relief_roll_angle(self: "Self", value: "float") -> None:
        self.wrapped.StartOfParabolicRootReliefRollAngle = (
            float(value) if value is not None else 0.0
        )

    @property
    def start_of_parabolic_root_relief_roll_distance(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.StartOfParabolicRootReliefRollDistance

        if temp is None:
            return 0.0

        return temp

    @start_of_parabolic_root_relief_roll_distance.setter
    @enforce_parameter_types
    def start_of_parabolic_root_relief_roll_distance(
        self: "Self", value: "float"
    ) -> None:
        self.wrapped.StartOfParabolicRootReliefRollDistance = (
            float(value) if value is not None else 0.0
        )

    @property
    def start_of_parabolic_tip_relief_diameter(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.StartOfParabolicTipReliefDiameter

        if temp is None:
            return 0.0

        return temp

    @start_of_parabolic_tip_relief_diameter.setter
    @enforce_parameter_types
    def start_of_parabolic_tip_relief_diameter(self: "Self", value: "float") -> None:
        self.wrapped.StartOfParabolicTipReliefDiameter = (
            float(value) if value is not None else 0.0
        )

    @property
    def start_of_parabolic_tip_relief_radius(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.StartOfParabolicTipReliefRadius

        if temp is None:
            return 0.0

        return temp

    @start_of_parabolic_tip_relief_radius.setter
    @enforce_parameter_types
    def start_of_parabolic_tip_relief_radius(self: "Self", value: "float") -> None:
        self.wrapped.StartOfParabolicTipReliefRadius = (
            float(value) if value is not None else 0.0
        )

    @property
    def start_of_parabolic_tip_relief_roll_angle(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.StartOfParabolicTipReliefRollAngle

        if temp is None:
            return 0.0

        return temp

    @start_of_parabolic_tip_relief_roll_angle.setter
    @enforce_parameter_types
    def start_of_parabolic_tip_relief_roll_angle(self: "Self", value: "float") -> None:
        self.wrapped.StartOfParabolicTipReliefRollAngle = (
            float(value) if value is not None else 0.0
        )

    @property
    def start_of_parabolic_tip_relief_roll_distance(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.StartOfParabolicTipReliefRollDistance

        if temp is None:
            return 0.0

        return temp

    @start_of_parabolic_tip_relief_roll_distance.setter
    @enforce_parameter_types
    def start_of_parabolic_tip_relief_roll_distance(
        self: "Self", value: "float"
    ) -> None:
        self.wrapped.StartOfParabolicTipReliefRollDistance = (
            float(value) if value is not None else 0.0
        )

    @property
    def use_measured_data(self: "Self") -> "bool":
        """bool"""
        temp = self.wrapped.UseMeasuredData

        if temp is None:
            return False

        return temp

    @use_measured_data.setter
    @enforce_parameter_types
    def use_measured_data(self: "Self", value: "bool") -> None:
        self.wrapped.UseMeasuredData = bool(value) if value is not None else False

    @property
    def barrelling_peak_point(
        self: "Self",
    ) -> "_1055.CylindricalGearProfileMeasurement":
        """mastapy._private.gears.gear_designs.cylindrical.CylindricalGearProfileMeasurement

        Note:
            This property is readonly.
        """
        temp = self.wrapped.BarrellingPeakPoint

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def evaluation_lower_limit(
        self: "Self",
    ) -> "_1055.CylindricalGearProfileMeasurement":
        """mastapy._private.gears.gear_designs.cylindrical.CylindricalGearProfileMeasurement

        Note:
            This property is readonly.
        """
        temp = self.wrapped.EvaluationLowerLimit

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def evaluation_lower_limit_for_zero_root_relief(
        self: "Self",
    ) -> "_1055.CylindricalGearProfileMeasurement":
        """mastapy._private.gears.gear_designs.cylindrical.CylindricalGearProfileMeasurement

        Note:
            This property is readonly.
        """
        temp = self.wrapped.EvaluationLowerLimitForZeroRootRelief

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def evaluation_upper_limit(
        self: "Self",
    ) -> "_1055.CylindricalGearProfileMeasurement":
        """mastapy._private.gears.gear_designs.cylindrical.CylindricalGearProfileMeasurement

        Note:
            This property is readonly.
        """
        temp = self.wrapped.EvaluationUpperLimit

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def evaluation_upper_limit_for_zero_tip_relief(
        self: "Self",
    ) -> "_1055.CylindricalGearProfileMeasurement":
        """mastapy._private.gears.gear_designs.cylindrical.CylindricalGearProfileMeasurement

        Note:
            This property is readonly.
        """
        temp = self.wrapped.EvaluationUpperLimitForZeroTipRelief

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def linear_root_relief_evaluation(
        self: "Self",
    ) -> "_1055.CylindricalGearProfileMeasurement":
        """mastapy._private.gears.gear_designs.cylindrical.CylindricalGearProfileMeasurement

        Note:
            This property is readonly.
        """
        temp = self.wrapped.LinearRootReliefEvaluation

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def linear_root_relief_start(
        self: "Self",
    ) -> "_1055.CylindricalGearProfileMeasurement":
        """mastapy._private.gears.gear_designs.cylindrical.CylindricalGearProfileMeasurement

        Note:
            This property is readonly.
        """
        temp = self.wrapped.LinearRootReliefStart

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def linear_tip_relief_evaluation(
        self: "Self",
    ) -> "_1055.CylindricalGearProfileMeasurement":
        """mastapy._private.gears.gear_designs.cylindrical.CylindricalGearProfileMeasurement

        Note:
            This property is readonly.
        """
        temp = self.wrapped.LinearTipReliefEvaluation

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def linear_tip_relief_start(
        self: "Self",
    ) -> "_1055.CylindricalGearProfileMeasurement":
        """mastapy._private.gears.gear_designs.cylindrical.CylindricalGearProfileMeasurement

        Note:
            This property is readonly.
        """
        temp = self.wrapped.LinearTipReliefStart

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def parabolic_root_relief_evaluation(
        self: "Self",
    ) -> "_1055.CylindricalGearProfileMeasurement":
        """mastapy._private.gears.gear_designs.cylindrical.CylindricalGearProfileMeasurement

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ParabolicRootReliefEvaluation

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def parabolic_root_relief_start(
        self: "Self",
    ) -> "_1055.CylindricalGearProfileMeasurement":
        """mastapy._private.gears.gear_designs.cylindrical.CylindricalGearProfileMeasurement

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ParabolicRootReliefStart

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def parabolic_tip_relief_evaluation(
        self: "Self",
    ) -> "_1055.CylindricalGearProfileMeasurement":
        """mastapy._private.gears.gear_designs.cylindrical.CylindricalGearProfileMeasurement

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ParabolicTipReliefEvaluation

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def parabolic_tip_relief_start(
        self: "Self",
    ) -> "_1055.CylindricalGearProfileMeasurement":
        """mastapy._private.gears.gear_designs.cylindrical.CylindricalGearProfileMeasurement

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ParabolicTipReliefStart

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def profile_modification_for_customer_102cad(
        self: "Self",
    ) -> "_1161.ProfileModificationForCustomer102CAD":
        """mastapy._private.gears.gear_designs.cylindrical.micro_geometry.ProfileModificationForCustomer102CAD

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ProfileModificationForCustomer102CAD

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @enforce_parameter_types
    def relief_of(self: "Self", roll_distance: "float") -> "float":
        """float

        Args:
            roll_distance (float)
        """
        roll_distance = float(roll_distance)
        method_result = self.wrapped.ReliefOf(roll_distance if roll_distance else 0.0)
        return method_result

    @property
    def cast_to(self: "Self") -> "_Cast_CylindricalGearProfileModification":
        """Cast to another type.

        Returns:
            _Cast_CylindricalGearProfileModification
        """
        return _Cast_CylindricalGearProfileModification(self)



"""ISO6336RateableMesh"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.type_enforcement import enforce_parameter_types
from mastapy._private._internal import constructor, conversion, utility
from mastapy._private.gears.rating.cylindrical import _482
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_ISO6336_RATEABLE_MESH = python_net_import(
    "SMT.MastaAPI.Gears.Rating.Cylindrical.ISO6336", "ISO6336RateableMesh"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.gears.rating.cylindrical import _489
    from mastapy._private.gears.rating.cylindrical.plastic_vdi2736 import (
        _504,
        _509,
        _510,
        _511,
    )
    from mastapy._private.gears.rating.cylindrical.iso6336 import _533
    from mastapy._private.gears.rating import _378

    Self = TypeVar("Self", bound="ISO6336RateableMesh")
    CastSelf = TypeVar(
        "CastSelf", bound="ISO6336RateableMesh._Cast_ISO6336RateableMesh"
    )


__docformat__ = "restructuredtext en"
__all__ = ("ISO6336RateableMesh",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_ISO6336RateableMesh:
    """Special nested class for casting ISO6336RateableMesh to subclasses."""

    __parent__: "ISO6336RateableMesh"

    @property
    def cylindrical_rateable_mesh(self: "CastSelf") -> "_482.CylindricalRateableMesh":
        return self.__parent__._cast(_482.CylindricalRateableMesh)

    @property
    def rateable_mesh(self: "CastSelf") -> "_378.RateableMesh":
        from mastapy._private.gears.rating import _378

        return self.__parent__._cast(_378.RateableMesh)

    @property
    def plastic_gear_vdi2736_abstract_rateable_mesh(
        self: "CastSelf",
    ) -> "_504.PlasticGearVDI2736AbstractRateableMesh":
        from mastapy._private.gears.rating.cylindrical.plastic_vdi2736 import _504

        return self.__parent__._cast(_504.PlasticGearVDI2736AbstractRateableMesh)

    @property
    def vdi2736_metal_plastic_rateable_mesh(
        self: "CastSelf",
    ) -> "_509.VDI2736MetalPlasticRateableMesh":
        from mastapy._private.gears.rating.cylindrical.plastic_vdi2736 import _509

        return self.__parent__._cast(_509.VDI2736MetalPlasticRateableMesh)

    @property
    def vdi2736_plastic_metal_rateable_mesh(
        self: "CastSelf",
    ) -> "_510.VDI2736PlasticMetalRateableMesh":
        from mastapy._private.gears.rating.cylindrical.plastic_vdi2736 import _510

        return self.__parent__._cast(_510.VDI2736PlasticMetalRateableMesh)

    @property
    def vdi2736_plastic_plastic_rateable_mesh(
        self: "CastSelf",
    ) -> "_511.VDI2736PlasticPlasticRateableMesh":
        from mastapy._private.gears.rating.cylindrical.plastic_vdi2736 import _511

        return self.__parent__._cast(_511.VDI2736PlasticPlasticRateableMesh)

    @property
    def iso6336_metal_rateable_mesh(
        self: "CastSelf",
    ) -> "_533.ISO6336MetalRateableMesh":
        from mastapy._private.gears.rating.cylindrical.iso6336 import _533

        return self.__parent__._cast(_533.ISO6336MetalRateableMesh)

    @property
    def iso6336_rateable_mesh(self: "CastSelf") -> "ISO6336RateableMesh":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class ISO6336RateableMesh(_482.CylindricalRateableMesh):
    """ISO6336RateableMesh

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _ISO6336_RATEABLE_MESH

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def misalignment_contact_pattern_enhancement(
        self: "Self",
    ) -> "_489.MisalignmentContactPatternEnhancements":
        """mastapy._private.gears.rating.cylindrical.MisalignmentContactPatternEnhancements"""
        temp = self.wrapped.MisalignmentContactPatternEnhancement

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp,
            "SMT.MastaAPI.Gears.Rating.Cylindrical.MisalignmentContactPatternEnhancements",
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.gears.rating.cylindrical._489",
            "MisalignmentContactPatternEnhancements",
        )(value)

    @misalignment_contact_pattern_enhancement.setter
    @enforce_parameter_types
    def misalignment_contact_pattern_enhancement(
        self: "Self", value: "_489.MisalignmentContactPatternEnhancements"
    ) -> None:
        value = conversion.mp_to_pn_enum(
            value,
            "SMT.MastaAPI.Gears.Rating.Cylindrical.MisalignmentContactPatternEnhancements",
        )
        self.wrapped.MisalignmentContactPatternEnhancement = value

    @property
    def cast_to(self: "Self") -> "_Cast_ISO6336RateableMesh":
        """Cast to another type.

        Returns:
            _Cast_ISO6336RateableMesh
        """
        return _Cast_ISO6336RateableMesh(self)



"""FEModel"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.type_enforcement import enforce_parameter_types
from mastapy._private._internal import constructor, conversion, utility
from mastapy._private import _0
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_FE_MODEL = python_net_import("SMT.MastaAPI.NodalAnalysis.DevToolsAnalyses", "FEModel")

if TYPE_CHECKING:
    from typing import Any, Type, List, TypeVar

    from mastapy._private.nodal_analysis.dev_tools_analyses import _210, _200
    from mastapy._private.nodal_analysis.dev_tools_analyses.full_fe_reporting import (
        _220,
        _214,
        _215,
        _221,
        _222,
        _228,
        _219,
        _223,
        _224,
        _225,
        _226,
        _218,
        _229,
    )

    Self = TypeVar("Self", bound="FEModel")
    CastSelf = TypeVar("CastSelf", bound="FEModel._Cast_FEModel")


__docformat__ = "restructuredtext en"
__all__ = ("FEModel",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_FEModel:
    """Special nested class for casting FEModel to subclasses."""

    __parent__: "FEModel"

    @property
    def fe_model(self: "CastSelf") -> "FEModel":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class FEModel(_0.APIBase):
    """FEModel

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _FE_MODEL

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def degree_of_neighbouring_faces_to_include(self: "Self") -> "int":
        """int"""
        temp = self.wrapped.DegreeOfNeighbouringFacesToInclude

        if temp is None:
            return 0

        return temp

    @degree_of_neighbouring_faces_to_include.setter
    @enforce_parameter_types
    def degree_of_neighbouring_faces_to_include(self: "Self", value: "int") -> None:
        self.wrapped.DegreeOfNeighbouringFacesToInclude = (
            int(value) if value is not None else 0
        )

    @property
    def edge_angle_tolerance(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.EdgeAngleTolerance

        if temp is None:
            return 0.0

        return temp

    @edge_angle_tolerance.setter
    @enforce_parameter_types
    def edge_angle_tolerance(self: "Self", value: "float") -> None:
        self.wrapped.EdgeAngleTolerance = float(value) if value is not None else 0.0

    @property
    def include_adjacent_faces_in_face_selection(self: "Self") -> "bool":
        """bool"""
        temp = self.wrapped.IncludeAdjacentFacesInFaceSelection

        if temp is None:
            return False

        return temp

    @include_adjacent_faces_in_face_selection.setter
    @enforce_parameter_types
    def include_adjacent_faces_in_face_selection(self: "Self", value: "bool") -> None:
        self.wrapped.IncludeAdjacentFacesInFaceSelection = (
            bool(value) if value is not None else False
        )

    @property
    def model_force_unit(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ModelForceUnit

        if temp is None:
            return ""

        return temp

    @property
    def model_length_unit(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ModelLengthUnit

        if temp is None:
            return ""

        return temp

    @property
    def model_splitting_method(self: "Self") -> "_210.ModelSplittingMethod":
        """mastapy._private.nodal_analysis.dev_tools_analyses.ModelSplittingMethod"""
        temp = self.wrapped.ModelSplittingMethod

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.NodalAnalysis.DevToolsAnalyses.ModelSplittingMethod"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.nodal_analysis.dev_tools_analyses._210",
            "ModelSplittingMethod",
        )(value)

    @model_splitting_method.setter
    @enforce_parameter_types
    def model_splitting_method(
        self: "Self", value: "_210.ModelSplittingMethod"
    ) -> None:
        value = conversion.mp_to_pn_enum(
            value, "SMT.MastaAPI.NodalAnalysis.DevToolsAnalyses.ModelSplittingMethod"
        )
        self.wrapped.ModelSplittingMethod = value

    @property
    def number_of_elements(self: "Self") -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = self.wrapped.NumberOfElements

        if temp is None:
            return 0

        return temp

    @property
    def number_of_elements_with_negative_jacobian(self: "Self") -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = self.wrapped.NumberOfElementsWithNegativeJacobian

        if temp is None:
            return 0

        return temp

    @property
    def number_of_elements_with_negative_size(self: "Self") -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = self.wrapped.NumberOfElementsWithNegativeSize

        if temp is None:
            return 0

        return temp

    @property
    def number_of_nodes(self: "Self") -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = self.wrapped.NumberOfNodes

        if temp is None:
            return 0

        return temp

    @property
    def original_file_path(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.OriginalFilePath

        if temp is None:
            return ""

        return temp

    @property
    def use_contact_pairs_for_boundary(self: "Self") -> "bool":
        """bool"""
        temp = self.wrapped.UseContactPairsForBoundary

        if temp is None:
            return False

        return temp

    @use_contact_pairs_for_boundary.setter
    @enforce_parameter_types
    def use_contact_pairs_for_boundary(self: "Self", value: "bool") -> None:
        self.wrapped.UseContactPairsForBoundary = (
            bool(value) if value is not None else False
        )

    @property
    def use_multipoint_constraints_for_boundary(self: "Self") -> "bool":
        """bool"""
        temp = self.wrapped.UseMultipointConstraintsForBoundary

        if temp is None:
            return False

        return temp

    @use_multipoint_constraints_for_boundary.setter
    @enforce_parameter_types
    def use_multipoint_constraints_for_boundary(self: "Self", value: "bool") -> None:
        self.wrapped.UseMultipointConstraintsForBoundary = (
            bool(value) if value is not None else False
        )

    @property
    def use_rigid_elements_for_boundary(self: "Self") -> "bool":
        """bool"""
        temp = self.wrapped.UseRigidElementsForBoundary

        if temp is None:
            return False

        return temp

    @use_rigid_elements_for_boundary.setter
    @enforce_parameter_types
    def use_rigid_elements_for_boundary(self: "Self", value: "bool") -> None:
        self.wrapped.UseRigidElementsForBoundary = (
            bool(value) if value is not None else False
        )

    @property
    def use_simplified_normal_calculation_when_deformed(self: "Self") -> "bool":
        """bool"""
        temp = self.wrapped.UseSimplifiedNormalCalculationWhenDeformed

        if temp is None:
            return False

        return temp

    @use_simplified_normal_calculation_when_deformed.setter
    @enforce_parameter_types
    def use_simplified_normal_calculation_when_deformed(
        self: "Self", value: "bool"
    ) -> None:
        self.wrapped.UseSimplifiedNormalCalculationWhenDeformed = (
            bool(value) if value is not None else False
        )

    @property
    def beam_element_properties(self: "Self") -> "List[_220.ElementPropertiesBeam]":
        """List[mastapy._private.nodal_analysis.dev_tools_analyses.full_fe_reporting.ElementPropertiesBeam]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.BeamElementProperties

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def contact_pairs(self: "Self") -> "List[_214.ContactPairReporting]":
        """List[mastapy._private.nodal_analysis.dev_tools_analyses.full_fe_reporting.ContactPairReporting]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ContactPairs

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def coordinate_systems(self: "Self") -> "List[_215.CoordinateSystemReporting]":
        """List[mastapy._private.nodal_analysis.dev_tools_analyses.full_fe_reporting.CoordinateSystemReporting]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.CoordinateSystems

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def interface_element_properties(
        self: "Self",
    ) -> "List[_221.ElementPropertiesInterface]":
        """List[mastapy._private.nodal_analysis.dev_tools_analyses.full_fe_reporting.ElementPropertiesInterface]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.InterfaceElementProperties

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def mass_element_properties(self: "Self") -> "List[_222.ElementPropertiesMass]":
        """List[mastapy._private.nodal_analysis.dev_tools_analyses.full_fe_reporting.ElementPropertiesMass]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MassElementProperties

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def materials(self: "Self") -> "List[_228.MaterialPropertiesReporting]":
        """List[mastapy._private.nodal_analysis.dev_tools_analyses.full_fe_reporting.MaterialPropertiesReporting]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Materials

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def model_parts(self: "Self") -> "List[_200.FEModelPart]":
        """List[mastapy._private.nodal_analysis.dev_tools_analyses.FEModelPart]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ModelParts

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def other_element_properties(self: "Self") -> "List[_219.ElementPropertiesBase]":
        """List[mastapy._private.nodal_analysis.dev_tools_analyses.full_fe_reporting.ElementPropertiesBase]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.OtherElementProperties

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def rigid_element_properties(self: "Self") -> "List[_223.ElementPropertiesRigid]":
        """List[mastapy._private.nodal_analysis.dev_tools_analyses.full_fe_reporting.ElementPropertiesRigid]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.RigidElementProperties

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def shell_element_properties(self: "Self") -> "List[_224.ElementPropertiesShell]":
        """List[mastapy._private.nodal_analysis.dev_tools_analyses.full_fe_reporting.ElementPropertiesShell]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ShellElementProperties

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def solid_element_properties(self: "Self") -> "List[_225.ElementPropertiesSolid]":
        """List[mastapy._private.nodal_analysis.dev_tools_analyses.full_fe_reporting.ElementPropertiesSolid]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SolidElementProperties

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def spring_dashpot_element_properties(
        self: "Self",
    ) -> "List[_226.ElementPropertiesSpringDashpot]":
        """List[mastapy._private.nodal_analysis.dev_tools_analyses.full_fe_reporting.ElementPropertiesSpringDashpot]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SpringDashpotElementProperties

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def report_names(self: "Self") -> "List[str]":
        """List[str]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ReportNames

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp, str)

        if value is None:
            return None

        return value

    def add_new_material(self: "Self") -> None:
        """Method does not return."""
        self.wrapped.AddNewMaterial()

    def change_interpolation_constraints_to_distributing(self: "Self") -> None:
        """Method does not return."""
        self.wrapped.ChangeInterpolationConstraintsToDistributing()

    def delete_unused_element_properties(self: "Self") -> None:
        """Method does not return."""
        self.wrapped.DeleteUnusedElementProperties()

    def delete_unused_materials(self: "Self") -> None:
        """Method does not return."""
        self.wrapped.DeleteUnusedMaterials()

    def get_all_element_details(self: "Self") -> "_218.ElementDetailsForFEModel":
        """mastapy._private.nodal_analysis.dev_tools_analyses.full_fe_reporting.ElementDetailsForFEModel"""
        method_result = self.wrapped.GetAllElementDetails()
        type_ = method_result.GetType()
        return (
            constructor.new(type_.Namespace, type_.Name)(method_result)
            if method_result is not None
            else None
        )

    def get_all_node_details(self: "Self") -> "_229.NodeDetailsForFEModel":
        """mastapy._private.nodal_analysis.dev_tools_analyses.full_fe_reporting.NodeDetailsForFEModel"""
        method_result = self.wrapped.GetAllNodeDetails()
        type_ = method_result.GetType()
        return (
            constructor.new(type_.Namespace, type_.Name)(method_result)
            if method_result is not None
            else None
        )

    @enforce_parameter_types
    def output_default_report_to(self: "Self", file_path: "str") -> None:
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        self.wrapped.OutputDefaultReportTo(file_path if file_path else "")

    def get_default_report_with_encoded_images(self: "Self") -> "str":
        """str"""
        method_result = self.wrapped.GetDefaultReportWithEncodedImages()
        return method_result

    @enforce_parameter_types
    def output_active_report_to(self: "Self", file_path: "str") -> None:
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        self.wrapped.OutputActiveReportTo(file_path if file_path else "")

    @enforce_parameter_types
    def output_active_report_as_text_to(self: "Self", file_path: "str") -> None:
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        self.wrapped.OutputActiveReportAsTextTo(file_path if file_path else "")

    def get_active_report_with_encoded_images(self: "Self") -> "str":
        """str"""
        method_result = self.wrapped.GetActiveReportWithEncodedImages()
        return method_result

    @enforce_parameter_types
    def output_named_report_to(
        self: "Self", report_name: "str", file_path: "str"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportTo(
            report_name if report_name else "", file_path if file_path else ""
        )

    @enforce_parameter_types
    def output_named_report_as_masta_report(
        self: "Self", report_name: "str", file_path: "str"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsMastaReport(
            report_name if report_name else "", file_path if file_path else ""
        )

    @enforce_parameter_types
    def output_named_report_as_text_to(
        self: "Self", report_name: "str", file_path: "str"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsTextTo(
            report_name if report_name else "", file_path if file_path else ""
        )

    @enforce_parameter_types
    def get_named_report_with_encoded_images(self: "Self", report_name: "str") -> "str":
        """str

        Args:
            report_name (str)
        """
        report_name = str(report_name)
        method_result = self.wrapped.GetNamedReportWithEncodedImages(
            report_name if report_name else ""
        )
        return method_result

    @property
    def cast_to(self: "Self") -> "_Cast_FEModel":
        """Cast to another type.

        Returns:
            _Cast_FEModel
        """
        return _Cast_FEModel(self)



"""SMTAxis"""
from __future__ import annotations

from typing import TYPE_CHECKING
from enum import Enum

from mastapy._private._internal.python_net import python_net_import

_SMT_AXIS = python_net_import("SMT.MastaAPI.UtilityGUI.Charts", "SMTAxis")

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="SMTAxis")
    CastSelf = TypeVar("CastSelf", bound="SMTAxis._Cast_SMTAxis")


__docformat__ = "restructuredtext en"
__all__ = ("SMTAxis",)


class SMTAxis(Enum):
    """SMTAxis

    This is a mastapy class.

    Note:
        This class is an Enum.
    """

    @classmethod
    def type_(cls) -> "Type":
        return _SMT_AXIS

    PRIMARYX = 0
    SECONDARYX = 1
    TERTIARYX = 2
    PRIMARYY = 3
    SECONDARYY = 4
    DEPTH = 5
    POLAR = 6
    POLARANGLE = 7
    I_ = 8
    J = 9
    RESULT = 10


def __enum_setattr(self: "Self", attr: str, value: "Any") -> None:
    raise AttributeError("Cannot set the attributes of an Enum.") from None


def __enum_delattr(self: "Self", attr: str) -> None:
    raise AttributeError("Cannot delete the attributes of an Enum.") from None


SMTAxis.__setattr__ = __enum_setattr
SMTAxis.__delattr__ = __enum_delattr



"""Subpackage."""

from typing import TYPE_CHECKING as __tc


if __tc:
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3336 import (
        AbstractAssemblySteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3337 import (
        AbstractShaftOrHousingSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3338 import (
        AbstractShaftSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3339 import (
        AbstractShaftToMountableComponentConnectionSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3340 import (
        AGMAGleasonConicalGearMeshSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3341 import (
        AGMAGleasonConicalGearSetSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3342 import (
        AGMAGleasonConicalGearSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3343 import (
        AssemblySteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3344 import (
        BearingSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3345 import (
        BeltConnectionSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3346 import (
        BeltDriveSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3347 import (
        BevelDifferentialGearMeshSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3348 import (
        BevelDifferentialGearSetSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3349 import (
        BevelDifferentialGearSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3350 import (
        BevelDifferentialPlanetGearSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3351 import (
        BevelDifferentialSunGearSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3352 import (
        BevelGearMeshSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3353 import (
        BevelGearSetSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3354 import (
        BevelGearSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3355 import (
        BoltedJointSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3356 import (
        BoltSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3357 import (
        ClutchConnectionSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3358 import (
        ClutchHalfSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3359 import (
        ClutchSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3360 import (
        CoaxialConnectionSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3361 import (
        ComponentSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3362 import (
        ConceptCouplingConnectionSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3363 import (
        ConceptCouplingHalfSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3364 import (
        ConceptCouplingSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3365 import (
        ConceptGearMeshSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3366 import (
        ConceptGearSetSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3367 import (
        ConceptGearSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3368 import (
        ConicalGearMeshSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3369 import (
        ConicalGearSetSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3370 import (
        ConicalGearSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3371 import (
        ConnectionSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3372 import (
        ConnectorSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3373 import (
        CouplingConnectionSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3374 import (
        CouplingHalfSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3375 import (
        CouplingSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3376 import (
        CVTBeltConnectionSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3377 import (
        CVTPulleySteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3378 import (
        CVTSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3379 import (
        CycloidalAssemblySteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3380 import (
        CycloidalDiscCentralBearingConnectionSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3381 import (
        CycloidalDiscPlanetaryBearingConnectionSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3382 import (
        CycloidalDiscSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3383 import (
        CylindricalGearMeshSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3384 import (
        CylindricalGearSetSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3385 import (
        CylindricalGearSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3386 import (
        CylindricalPlanetGearSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3387 import (
        DatumSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3388 import (
        ExternalCADModelSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3389 import (
        FaceGearMeshSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3390 import (
        FaceGearSetSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3391 import (
        FaceGearSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3392 import (
        FEPartSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3393 import (
        FlexiblePinAssemblySteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3394 import (
        GearMeshSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3395 import (
        GearSetSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3396 import (
        GearSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3397 import (
        GuideDxfModelSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3398 import (
        HypoidGearMeshSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3399 import (
        HypoidGearSetSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3400 import (
        HypoidGearSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3401 import (
        InterMountableComponentConnectionSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3402 import (
        KlingelnbergCycloPalloidConicalGearMeshSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3403 import (
        KlingelnbergCycloPalloidConicalGearSetSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3404 import (
        KlingelnbergCycloPalloidConicalGearSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3405 import (
        KlingelnbergCycloPalloidHypoidGearMeshSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3406 import (
        KlingelnbergCycloPalloidHypoidGearSetSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3407 import (
        KlingelnbergCycloPalloidHypoidGearSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3408 import (
        KlingelnbergCycloPalloidSpiralBevelGearMeshSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3409 import (
        KlingelnbergCycloPalloidSpiralBevelGearSetSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3410 import (
        KlingelnbergCycloPalloidSpiralBevelGearSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3411 import (
        MassDiscSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3412 import (
        MeasurementComponentSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3413 import (
        MicrophoneArraySteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3414 import (
        MicrophoneSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3415 import (
        MountableComponentSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3416 import (
        OilSealSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3417 import (
        PartSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3418 import (
        PartToPartShearCouplingConnectionSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3419 import (
        PartToPartShearCouplingHalfSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3420 import (
        PartToPartShearCouplingSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3421 import (
        PlanetaryConnectionSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3422 import (
        PlanetaryGearSetSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3423 import (
        PlanetCarrierSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3424 import (
        PointLoadSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3425 import (
        PowerLoadSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3426 import (
        PulleySteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3427 import (
        RingPinsSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3428 import (
        RingPinsToDiscConnectionSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3429 import (
        RollingRingAssemblySteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3430 import (
        RollingRingConnectionSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3431 import (
        RollingRingSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3432 import (
        RootAssemblySteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3433 import (
        ShaftHubConnectionSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3434 import (
        ShaftSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3435 import (
        ShaftToMountableComponentConnectionSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3436 import (
        SpecialisedAssemblySteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3437 import (
        SpiralBevelGearMeshSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3438 import (
        SpiralBevelGearSetSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3439 import (
        SpiralBevelGearSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3440 import (
        SpringDamperConnectionSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3441 import (
        SpringDamperHalfSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3442 import (
        SpringDamperSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3443 import (
        SteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3444 import (
        StraightBevelDiffGearMeshSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3445 import (
        StraightBevelDiffGearSetSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3446 import (
        StraightBevelDiffGearSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3447 import (
        StraightBevelGearMeshSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3448 import (
        StraightBevelGearSetSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3449 import (
        StraightBevelGearSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3450 import (
        StraightBevelPlanetGearSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3451 import (
        StraightBevelSunGearSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3452 import (
        SynchroniserHalfSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3453 import (
        SynchroniserPartSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3454 import (
        SynchroniserSleeveSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3455 import (
        SynchroniserSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3456 import (
        TorqueConverterConnectionSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3457 import (
        TorqueConverterPumpSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3458 import (
        TorqueConverterSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3459 import (
        TorqueConverterTurbineSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3460 import (
        UnbalancedMassSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3461 import (
        VirtualComponentSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3462 import (
        WormGearMeshSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3463 import (
        WormGearSetSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3464 import (
        WormGearSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3465 import (
        ZerolBevelGearMeshSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3466 import (
        ZerolBevelGearSetSteadyStateSynchronousResponseOnAShaft,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3467 import (
        ZerolBevelGearSteadyStateSynchronousResponseOnAShaft,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3336": [
            "AbstractAssemblySteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3337": [
            "AbstractShaftOrHousingSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3338": [
            "AbstractShaftSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3339": [
            "AbstractShaftToMountableComponentConnectionSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3340": [
            "AGMAGleasonConicalGearMeshSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3341": [
            "AGMAGleasonConicalGearSetSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3342": [
            "AGMAGleasonConicalGearSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3343": [
            "AssemblySteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3344": [
            "BearingSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3345": [
            "BeltConnectionSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3346": [
            "BeltDriveSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3347": [
            "BevelDifferentialGearMeshSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3348": [
            "BevelDifferentialGearSetSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3349": [
            "BevelDifferentialGearSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3350": [
            "BevelDifferentialPlanetGearSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3351": [
            "BevelDifferentialSunGearSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3352": [
            "BevelGearMeshSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3353": [
            "BevelGearSetSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3354": [
            "BevelGearSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3355": [
            "BoltedJointSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3356": [
            "BoltSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3357": [
            "ClutchConnectionSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3358": [
            "ClutchHalfSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3359": [
            "ClutchSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3360": [
            "CoaxialConnectionSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3361": [
            "ComponentSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3362": [
            "ConceptCouplingConnectionSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3363": [
            "ConceptCouplingHalfSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3364": [
            "ConceptCouplingSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3365": [
            "ConceptGearMeshSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3366": [
            "ConceptGearSetSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3367": [
            "ConceptGearSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3368": [
            "ConicalGearMeshSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3369": [
            "ConicalGearSetSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3370": [
            "ConicalGearSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3371": [
            "ConnectionSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3372": [
            "ConnectorSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3373": [
            "CouplingConnectionSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3374": [
            "CouplingHalfSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3375": [
            "CouplingSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3376": [
            "CVTBeltConnectionSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3377": [
            "CVTPulleySteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3378": [
            "CVTSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3379": [
            "CycloidalAssemblySteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3380": [
            "CycloidalDiscCentralBearingConnectionSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3381": [
            "CycloidalDiscPlanetaryBearingConnectionSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3382": [
            "CycloidalDiscSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3383": [
            "CylindricalGearMeshSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3384": [
            "CylindricalGearSetSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3385": [
            "CylindricalGearSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3386": [
            "CylindricalPlanetGearSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3387": [
            "DatumSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3388": [
            "ExternalCADModelSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3389": [
            "FaceGearMeshSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3390": [
            "FaceGearSetSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3391": [
            "FaceGearSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3392": [
            "FEPartSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3393": [
            "FlexiblePinAssemblySteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3394": [
            "GearMeshSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3395": [
            "GearSetSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3396": [
            "GearSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3397": [
            "GuideDxfModelSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3398": [
            "HypoidGearMeshSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3399": [
            "HypoidGearSetSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3400": [
            "HypoidGearSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3401": [
            "InterMountableComponentConnectionSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3402": [
            "KlingelnbergCycloPalloidConicalGearMeshSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3403": [
            "KlingelnbergCycloPalloidConicalGearSetSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3404": [
            "KlingelnbergCycloPalloidConicalGearSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3405": [
            "KlingelnbergCycloPalloidHypoidGearMeshSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3406": [
            "KlingelnbergCycloPalloidHypoidGearSetSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3407": [
            "KlingelnbergCycloPalloidHypoidGearSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3408": [
            "KlingelnbergCycloPalloidSpiralBevelGearMeshSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3409": [
            "KlingelnbergCycloPalloidSpiralBevelGearSetSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3410": [
            "KlingelnbergCycloPalloidSpiralBevelGearSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3411": [
            "MassDiscSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3412": [
            "MeasurementComponentSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3413": [
            "MicrophoneArraySteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3414": [
            "MicrophoneSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3415": [
            "MountableComponentSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3416": [
            "OilSealSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3417": [
            "PartSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3418": [
            "PartToPartShearCouplingConnectionSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3419": [
            "PartToPartShearCouplingHalfSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3420": [
            "PartToPartShearCouplingSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3421": [
            "PlanetaryConnectionSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3422": [
            "PlanetaryGearSetSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3423": [
            "PlanetCarrierSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3424": [
            "PointLoadSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3425": [
            "PowerLoadSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3426": [
            "PulleySteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3427": [
            "RingPinsSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3428": [
            "RingPinsToDiscConnectionSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3429": [
            "RollingRingAssemblySteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3430": [
            "RollingRingConnectionSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3431": [
            "RollingRingSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3432": [
            "RootAssemblySteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3433": [
            "ShaftHubConnectionSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3434": [
            "ShaftSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3435": [
            "ShaftToMountableComponentConnectionSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3436": [
            "SpecialisedAssemblySteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3437": [
            "SpiralBevelGearMeshSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3438": [
            "SpiralBevelGearSetSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3439": [
            "SpiralBevelGearSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3440": [
            "SpringDamperConnectionSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3441": [
            "SpringDamperHalfSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3442": [
            "SpringDamperSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3443": [
            "SteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3444": [
            "StraightBevelDiffGearMeshSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3445": [
            "StraightBevelDiffGearSetSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3446": [
            "StraightBevelDiffGearSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3447": [
            "StraightBevelGearMeshSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3448": [
            "StraightBevelGearSetSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3449": [
            "StraightBevelGearSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3450": [
            "StraightBevelPlanetGearSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3451": [
            "StraightBevelSunGearSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3452": [
            "SynchroniserHalfSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3453": [
            "SynchroniserPartSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3454": [
            "SynchroniserSleeveSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3455": [
            "SynchroniserSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3456": [
            "TorqueConverterConnectionSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3457": [
            "TorqueConverterPumpSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3458": [
            "TorqueConverterSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3459": [
            "TorqueConverterTurbineSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3460": [
            "UnbalancedMassSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3461": [
            "VirtualComponentSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3462": [
            "WormGearMeshSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3463": [
            "WormGearSetSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3464": [
            "WormGearSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3465": [
            "ZerolBevelGearMeshSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3466": [
            "ZerolBevelGearSetSteadyStateSynchronousResponseOnAShaft"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft._3467": [
            "ZerolBevelGearSteadyStateSynchronousResponseOnAShaft"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AbstractAssemblySteadyStateSynchronousResponseOnAShaft",
    "AbstractShaftOrHousingSteadyStateSynchronousResponseOnAShaft",
    "AbstractShaftSteadyStateSynchronousResponseOnAShaft",
    "AbstractShaftToMountableComponentConnectionSteadyStateSynchronousResponseOnAShaft",
    "AGMAGleasonConicalGearMeshSteadyStateSynchronousResponseOnAShaft",
    "AGMAGleasonConicalGearSetSteadyStateSynchronousResponseOnAShaft",
    "AGMAGleasonConicalGearSteadyStateSynchronousResponseOnAShaft",
    "AssemblySteadyStateSynchronousResponseOnAShaft",
    "BearingSteadyStateSynchronousResponseOnAShaft",
    "BeltConnectionSteadyStateSynchronousResponseOnAShaft",
    "BeltDriveSteadyStateSynchronousResponseOnAShaft",
    "BevelDifferentialGearMeshSteadyStateSynchronousResponseOnAShaft",
    "BevelDifferentialGearSetSteadyStateSynchronousResponseOnAShaft",
    "BevelDifferentialGearSteadyStateSynchronousResponseOnAShaft",
    "BevelDifferentialPlanetGearSteadyStateSynchronousResponseOnAShaft",
    "BevelDifferentialSunGearSteadyStateSynchronousResponseOnAShaft",
    "BevelGearMeshSteadyStateSynchronousResponseOnAShaft",
    "BevelGearSetSteadyStateSynchronousResponseOnAShaft",
    "BevelGearSteadyStateSynchronousResponseOnAShaft",
    "BoltedJointSteadyStateSynchronousResponseOnAShaft",
    "BoltSteadyStateSynchronousResponseOnAShaft",
    "ClutchConnectionSteadyStateSynchronousResponseOnAShaft",
    "ClutchHalfSteadyStateSynchronousResponseOnAShaft",
    "ClutchSteadyStateSynchronousResponseOnAShaft",
    "CoaxialConnectionSteadyStateSynchronousResponseOnAShaft",
    "ComponentSteadyStateSynchronousResponseOnAShaft",
    "ConceptCouplingConnectionSteadyStateSynchronousResponseOnAShaft",
    "ConceptCouplingHalfSteadyStateSynchronousResponseOnAShaft",
    "ConceptCouplingSteadyStateSynchronousResponseOnAShaft",
    "ConceptGearMeshSteadyStateSynchronousResponseOnAShaft",
    "ConceptGearSetSteadyStateSynchronousResponseOnAShaft",
    "ConceptGearSteadyStateSynchronousResponseOnAShaft",
    "ConicalGearMeshSteadyStateSynchronousResponseOnAShaft",
    "ConicalGearSetSteadyStateSynchronousResponseOnAShaft",
    "ConicalGearSteadyStateSynchronousResponseOnAShaft",
    "ConnectionSteadyStateSynchronousResponseOnAShaft",
    "ConnectorSteadyStateSynchronousResponseOnAShaft",
    "CouplingConnectionSteadyStateSynchronousResponseOnAShaft",
    "CouplingHalfSteadyStateSynchronousResponseOnAShaft",
    "CouplingSteadyStateSynchronousResponseOnAShaft",
    "CVTBeltConnectionSteadyStateSynchronousResponseOnAShaft",
    "CVTPulleySteadyStateSynchronousResponseOnAShaft",
    "CVTSteadyStateSynchronousResponseOnAShaft",
    "CycloidalAssemblySteadyStateSynchronousResponseOnAShaft",
    "CycloidalDiscCentralBearingConnectionSteadyStateSynchronousResponseOnAShaft",
    "CycloidalDiscPlanetaryBearingConnectionSteadyStateSynchronousResponseOnAShaft",
    "CycloidalDiscSteadyStateSynchronousResponseOnAShaft",
    "CylindricalGearMeshSteadyStateSynchronousResponseOnAShaft",
    "CylindricalGearSetSteadyStateSynchronousResponseOnAShaft",
    "CylindricalGearSteadyStateSynchronousResponseOnAShaft",
    "CylindricalPlanetGearSteadyStateSynchronousResponseOnAShaft",
    "DatumSteadyStateSynchronousResponseOnAShaft",
    "ExternalCADModelSteadyStateSynchronousResponseOnAShaft",
    "FaceGearMeshSteadyStateSynchronousResponseOnAShaft",
    "FaceGearSetSteadyStateSynchronousResponseOnAShaft",
    "FaceGearSteadyStateSynchronousResponseOnAShaft",
    "FEPartSteadyStateSynchronousResponseOnAShaft",
    "FlexiblePinAssemblySteadyStateSynchronousResponseOnAShaft",
    "GearMeshSteadyStateSynchronousResponseOnAShaft",
    "GearSetSteadyStateSynchronousResponseOnAShaft",
    "GearSteadyStateSynchronousResponseOnAShaft",
    "GuideDxfModelSteadyStateSynchronousResponseOnAShaft",
    "HypoidGearMeshSteadyStateSynchronousResponseOnAShaft",
    "HypoidGearSetSteadyStateSynchronousResponseOnAShaft",
    "HypoidGearSteadyStateSynchronousResponseOnAShaft",
    "InterMountableComponentConnectionSteadyStateSynchronousResponseOnAShaft",
    "KlingelnbergCycloPalloidConicalGearMeshSteadyStateSynchronousResponseOnAShaft",
    "KlingelnbergCycloPalloidConicalGearSetSteadyStateSynchronousResponseOnAShaft",
    "KlingelnbergCycloPalloidConicalGearSteadyStateSynchronousResponseOnAShaft",
    "KlingelnbergCycloPalloidHypoidGearMeshSteadyStateSynchronousResponseOnAShaft",
    "KlingelnbergCycloPalloidHypoidGearSetSteadyStateSynchronousResponseOnAShaft",
    "KlingelnbergCycloPalloidHypoidGearSteadyStateSynchronousResponseOnAShaft",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshSteadyStateSynchronousResponseOnAShaft",
    "KlingelnbergCycloPalloidSpiralBevelGearSetSteadyStateSynchronousResponseOnAShaft",
    "KlingelnbergCycloPalloidSpiralBevelGearSteadyStateSynchronousResponseOnAShaft",
    "MassDiscSteadyStateSynchronousResponseOnAShaft",
    "MeasurementComponentSteadyStateSynchronousResponseOnAShaft",
    "MicrophoneArraySteadyStateSynchronousResponseOnAShaft",
    "MicrophoneSteadyStateSynchronousResponseOnAShaft",
    "MountableComponentSteadyStateSynchronousResponseOnAShaft",
    "OilSealSteadyStateSynchronousResponseOnAShaft",
    "PartSteadyStateSynchronousResponseOnAShaft",
    "PartToPartShearCouplingConnectionSteadyStateSynchronousResponseOnAShaft",
    "PartToPartShearCouplingHalfSteadyStateSynchronousResponseOnAShaft",
    "PartToPartShearCouplingSteadyStateSynchronousResponseOnAShaft",
    "PlanetaryConnectionSteadyStateSynchronousResponseOnAShaft",
    "PlanetaryGearSetSteadyStateSynchronousResponseOnAShaft",
    "PlanetCarrierSteadyStateSynchronousResponseOnAShaft",
    "PointLoadSteadyStateSynchronousResponseOnAShaft",
    "PowerLoadSteadyStateSynchronousResponseOnAShaft",
    "PulleySteadyStateSynchronousResponseOnAShaft",
    "RingPinsSteadyStateSynchronousResponseOnAShaft",
    "RingPinsToDiscConnectionSteadyStateSynchronousResponseOnAShaft",
    "RollingRingAssemblySteadyStateSynchronousResponseOnAShaft",
    "RollingRingConnectionSteadyStateSynchronousResponseOnAShaft",
    "RollingRingSteadyStateSynchronousResponseOnAShaft",
    "RootAssemblySteadyStateSynchronousResponseOnAShaft",
    "ShaftHubConnectionSteadyStateSynchronousResponseOnAShaft",
    "ShaftSteadyStateSynchronousResponseOnAShaft",
    "ShaftToMountableComponentConnectionSteadyStateSynchronousResponseOnAShaft",
    "SpecialisedAssemblySteadyStateSynchronousResponseOnAShaft",
    "SpiralBevelGearMeshSteadyStateSynchronousResponseOnAShaft",
    "SpiralBevelGearSetSteadyStateSynchronousResponseOnAShaft",
    "SpiralBevelGearSteadyStateSynchronousResponseOnAShaft",
    "SpringDamperConnectionSteadyStateSynchronousResponseOnAShaft",
    "SpringDamperHalfSteadyStateSynchronousResponseOnAShaft",
    "SpringDamperSteadyStateSynchronousResponseOnAShaft",
    "SteadyStateSynchronousResponseOnAShaft",
    "StraightBevelDiffGearMeshSteadyStateSynchronousResponseOnAShaft",
    "StraightBevelDiffGearSetSteadyStateSynchronousResponseOnAShaft",
    "StraightBevelDiffGearSteadyStateSynchronousResponseOnAShaft",
    "StraightBevelGearMeshSteadyStateSynchronousResponseOnAShaft",
    "StraightBevelGearSetSteadyStateSynchronousResponseOnAShaft",
    "StraightBevelGearSteadyStateSynchronousResponseOnAShaft",
    "StraightBevelPlanetGearSteadyStateSynchronousResponseOnAShaft",
    "StraightBevelSunGearSteadyStateSynchronousResponseOnAShaft",
    "SynchroniserHalfSteadyStateSynchronousResponseOnAShaft",
    "SynchroniserPartSteadyStateSynchronousResponseOnAShaft",
    "SynchroniserSleeveSteadyStateSynchronousResponseOnAShaft",
    "SynchroniserSteadyStateSynchronousResponseOnAShaft",
    "TorqueConverterConnectionSteadyStateSynchronousResponseOnAShaft",
    "TorqueConverterPumpSteadyStateSynchronousResponseOnAShaft",
    "TorqueConverterSteadyStateSynchronousResponseOnAShaft",
    "TorqueConverterTurbineSteadyStateSynchronousResponseOnAShaft",
    "UnbalancedMassSteadyStateSynchronousResponseOnAShaft",
    "VirtualComponentSteadyStateSynchronousResponseOnAShaft",
    "WormGearMeshSteadyStateSynchronousResponseOnAShaft",
    "WormGearSetSteadyStateSynchronousResponseOnAShaft",
    "WormGearSteadyStateSynchronousResponseOnAShaft",
    "ZerolBevelGearMeshSteadyStateSynchronousResponseOnAShaft",
    "ZerolBevelGearSetSteadyStateSynchronousResponseOnAShaft",
    "ZerolBevelGearSteadyStateSynchronousResponseOnAShaft",
)



"""UserTextRow"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.type_enforcement import enforce_parameter_types
from mastapy._private._internal import constructor, conversion, utility
from mastapy._private.utility.report import _1826
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_USER_TEXT_ROW = python_net_import("SMT.MastaAPI.Utility.Report", "UserTextRow")

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.utility.report import _1833, _1821

    Self = TypeVar("Self", bound="UserTextRow")
    CastSelf = TypeVar("CastSelf", bound="UserTextRow._Cast_UserTextRow")


__docformat__ = "restructuredtext en"
__all__ = ("UserTextRow",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_UserTextRow:
    """Special nested class for casting UserTextRow to subclasses."""

    __parent__: "UserTextRow"

    @property
    def custom_row(self: "CastSelf") -> "_1826.CustomRow":
        return self.__parent__._cast(_1826.CustomRow)

    @property
    def custom_report_property_item(
        self: "CastSelf",
    ) -> "_1821.CustomReportPropertyItem":
        from mastapy._private.utility.report import _1821

        return self.__parent__._cast(_1821.CustomReportPropertyItem)

    @property
    def user_text_row(self: "CastSelf") -> "UserTextRow":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class UserTextRow(_1826.CustomRow):
    """UserTextRow

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _USER_TEXT_ROW

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def additional_text(self: "Self") -> "str":
        """str"""
        temp = self.wrapped.AdditionalText

        if temp is None:
            return ""

        return temp

    @additional_text.setter
    @enforce_parameter_types
    def additional_text(self: "Self", value: "str") -> None:
        self.wrapped.AdditionalText = str(value) if value is not None else ""

    @property
    def heading_size(self: "Self") -> "_1833.HeadingSize":
        """mastapy._private.utility.report.HeadingSize"""
        temp = self.wrapped.HeadingSize

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.Utility.Report.HeadingSize"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.utility.report._1833", "HeadingSize"
        )(value)

    @heading_size.setter
    @enforce_parameter_types
    def heading_size(self: "Self", value: "_1833.HeadingSize") -> None:
        value = conversion.mp_to_pn_enum(
            value, "SMT.MastaAPI.Utility.Report.HeadingSize"
        )
        self.wrapped.HeadingSize = value

    @property
    def is_heading(self: "Self") -> "bool":
        """bool"""
        temp = self.wrapped.IsHeading

        if temp is None:
            return False

        return temp

    @is_heading.setter
    @enforce_parameter_types
    def is_heading(self: "Self", value: "bool") -> None:
        self.wrapped.IsHeading = bool(value) if value is not None else False

    @property
    def show_additional_text(self: "Self") -> "bool":
        """bool"""
        temp = self.wrapped.ShowAdditionalText

        if temp is None:
            return False

        return temp

    @show_additional_text.setter
    @enforce_parameter_types
    def show_additional_text(self: "Self", value: "bool") -> None:
        self.wrapped.ShowAdditionalText = bool(value) if value is not None else False

    @property
    def text(self: "Self") -> "str":
        """str"""
        temp = self.wrapped.Text

        if temp is None:
            return ""

        return temp

    @text.setter
    @enforce_parameter_types
    def text(self: "Self", value: "str") -> None:
        self.wrapped.Text = str(value) if value is not None else ""

    @property
    def cast_to(self: "Self") -> "_Cast_UserTextRow":
        """Cast to another type.

        Returns:
            _Cast_UserTextRow
        """
        return _Cast_UserTextRow(self)



"""Subpackage."""

from typing import TYPE_CHECKING as __tc


if __tc:
    from mastapy._private.gears.gear_two_d_fe_analysis._917 import (
        CylindricalGearMeshTIFFAnalysis,
    )
    from mastapy._private.gears.gear_two_d_fe_analysis._918 import (
        CylindricalGearMeshTIFFAnalysisDutyCycle,
    )
    from mastapy._private.gears.gear_two_d_fe_analysis._919 import (
        CylindricalGearSetTIFFAnalysis,
    )
    from mastapy._private.gears.gear_two_d_fe_analysis._920 import (
        CylindricalGearSetTIFFAnalysisDutyCycle,
    )
    from mastapy._private.gears.gear_two_d_fe_analysis._921 import (
        CylindricalGearTIFFAnalysis,
    )
    from mastapy._private.gears.gear_two_d_fe_analysis._922 import (
        CylindricalGearTIFFAnalysisDutyCycle,
    )
    from mastapy._private.gears.gear_two_d_fe_analysis._923 import (
        CylindricalGearTwoDimensionalFEAnalysis,
    )
    from mastapy._private.gears.gear_two_d_fe_analysis._924 import (
        FindleyCriticalPlaneAnalysis,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.gears.gear_two_d_fe_analysis._917": [
            "CylindricalGearMeshTIFFAnalysis"
        ],
        "_private.gears.gear_two_d_fe_analysis._918": [
            "CylindricalGearMeshTIFFAnalysisDutyCycle"
        ],
        "_private.gears.gear_two_d_fe_analysis._919": [
            "CylindricalGearSetTIFFAnalysis"
        ],
        "_private.gears.gear_two_d_fe_analysis._920": [
            "CylindricalGearSetTIFFAnalysisDutyCycle"
        ],
        "_private.gears.gear_two_d_fe_analysis._921": ["CylindricalGearTIFFAnalysis"],
        "_private.gears.gear_two_d_fe_analysis._922": [
            "CylindricalGearTIFFAnalysisDutyCycle"
        ],
        "_private.gears.gear_two_d_fe_analysis._923": [
            "CylindricalGearTwoDimensionalFEAnalysis"
        ],
        "_private.gears.gear_two_d_fe_analysis._924": ["FindleyCriticalPlaneAnalysis"],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "CylindricalGearMeshTIFFAnalysis",
    "CylindricalGearMeshTIFFAnalysisDutyCycle",
    "CylindricalGearSetTIFFAnalysis",
    "CylindricalGearSetTIFFAnalysisDutyCycle",
    "CylindricalGearTIFFAnalysis",
    "CylindricalGearTIFFAnalysisDutyCycle",
    "CylindricalGearTwoDimensionalFEAnalysis",
    "FindleyCriticalPlaneAnalysis",
)



"""FEModelComponentDrawStyle"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.type_enforcement import enforce_parameter_types
from mastapy._private._internal import utility
from mastapy._private import _0
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_FE_MODEL_COMPONENT_DRAW_STYLE = python_net_import(
    "SMT.MastaAPI.NodalAnalysis.DevToolsAnalyses", "FEModelComponentDrawStyle"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="FEModelComponentDrawStyle")
    CastSelf = TypeVar(
        "CastSelf", bound="FEModelComponentDrawStyle._Cast_FEModelComponentDrawStyle"
    )


__docformat__ = "restructuredtext en"
__all__ = ("FEModelComponentDrawStyle",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_FEModelComponentDrawStyle:
    """Special nested class for casting FEModelComponentDrawStyle to subclasses."""

    __parent__: "FEModelComponentDrawStyle"

    @property
    def fe_model_component_draw_style(self: "CastSelf") -> "FEModelComponentDrawStyle":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class FEModelComponentDrawStyle(_0.APIBase):
    """FEModelComponentDrawStyle

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _FE_MODEL_COMPONENT_DRAW_STYLE

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def connectable_components(self: "Self") -> "bool":
        """bool"""
        temp = self.wrapped.ConnectableComponents

        if temp is None:
            return False

        return temp

    @connectable_components.setter
    @enforce_parameter_types
    def connectable_components(self: "Self", value: "bool") -> None:
        self.wrapped.ConnectableComponents = bool(value) if value is not None else False

    @property
    def solid_components(self: "Self") -> "bool":
        """bool"""
        temp = self.wrapped.SolidComponents

        if temp is None:
            return False

        return temp

    @solid_components.setter
    @enforce_parameter_types
    def solid_components(self: "Self", value: "bool") -> None:
        self.wrapped.SolidComponents = bool(value) if value is not None else False

    @property
    def solid_shafts(self: "Self") -> "bool":
        """bool"""
        temp = self.wrapped.SolidShafts

        if temp is None:
            return False

        return temp

    @solid_shafts.setter
    @enforce_parameter_types
    def solid_shafts(self: "Self", value: "bool") -> None:
        self.wrapped.SolidShafts = bool(value) if value is not None else False

    @property
    def transparent_model(self: "Self") -> "bool":
        """bool"""
        temp = self.wrapped.TransparentModel

        if temp is None:
            return False

        return temp

    @transparent_model.setter
    @enforce_parameter_types
    def transparent_model(self: "Self", value: "bool") -> None:
        self.wrapped.TransparentModel = bool(value) if value is not None else False

    @property
    def cast_to(self: "Self") -> "_Cast_FEModelComponentDrawStyle":
        """Cast to another type.

        Returns:
            _Cast_FEModelComponentDrawStyle
        """
        return _Cast_FEModelComponentDrawStyle(self)
